stac.nonparametric_tests.friedman_aligned_ranks_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.friedman_aligned_ranks_test

`stac.nonparametric_tests.` `friedman_aligned_ranks_test`(*args)

  Performs a Friedman aligned ranks ranking test. Tests the hypothesis that in a set of k dependent samples groups (where k >= 2) at least two of the groups represent populations with different median values. The difference with a friedman test is that it uses the median of each group to construct the ranking, which is useful when the number of samples is low.

  Parameters: | sample1, sample2, ... : array_like The sample measurements for each group.
  Returns: | Chi2-value : float The computed Chi2-value of the test. p-value : float The associated p-value from the Chi2-distribution. rankings : array_like The ranking for each group. pivots : array_like The pivotal quantities for each group.

### Navigation

- index
- STAC Release Candidate documentation »